#!/bin/bash

RUNTIME_HOME=./runtime
export PATH=$RUNTIME_HOME/bin:$PATH

# Store type can be pkcs12 or jsk
KEYSTORE_FILE_TYPE=pkcs12
KEYSTORE_FILE=tcmp_keystore

# Keys-store and key passwords
KEYSTORE_PWD=talend
KEY_PWD=talend

# Customize the following distinguished name (DNAME) template as necessary
#
# CN="common name"
# OU="organization unit"
# O="organization"
# L="locality/city"
# S="state/province"
# C="country"
#
DNAME="CN=, OU=CustomerSuccess, O=Talend Inc., L=Redwood City, S=California, C=US"

# Self-Signed certificate alias for 'tcmp'
ALIAS=tcmp

SSL_SERVER_PORT=7778
TCMP_HTTPS_SCRIPT=tcmp_https_start.sh

echo - ---------------------------------------------------------
echo
echo This script will configure TCMP for HTTPS connection.
echo
echo The script creates a java keystore with a self-signed certificate and
echo "create a new TCMP start script '$TCMP_HTTPS_SCRIPT' configured for SSL/HTTPS."
echo You can use this script to start tcmp with HTTPS support.
echo
echo "  Review the following configuration properties before to proceed:"
echo "    KEYSTORE_FILE_TYPE = $KEYSTORE_FILE_TYPE"
echo "    KEYSTORE_FILE = $KEYSTORE_FILE"
echo "    KEYSTORE_PWD = $KEYSTORE_PWD"
echo "    KEY_PWD = $KEY_PWD"
echo "    DNAME = $DNAME"
echo "    ALIAS = $ALIAS"
echo "    SSL_SERVER_PORT = $SSL_SERVER_PORT (port under < 1024 will require to run tcmp as root/sudo)"
echo "    TCMP_HTTPS_SCRIPT = $TCMP_HTTPS_SCRIPT"
echo
echo 'If you want to change these values, stop and update this script; otherwise, continue.'

read -r -n 1 -t 5 -p "Press enter to continue."

rm -f $KEYSTORE_FILE
rm -f $TCMP_HTTPS_SCRIPT
echo - ---------------------------------------------------------
echo - Create a keystore file with a self-signed Certificate
echo   - Alias : $ALIAS
echo   - DNAME : $DNAME
echo   - Keystore: $KEYSTORE_FILE
echo - ---------------------------------------------------------
keytool \
-genkeypair \
-alias $ALIAS \
-dname "$DNAME" \
-keystore $KEYSTORE_FILE \
-storetype $KEYSTORE_FILE_TYPE \
-keypass $KEY_PWD \
-storepass $KEYSTORE_PWD \
-keyalg RSA \
-keysize 2048 \
-validity 365

echo - keystore created
echo - ---------------------------------------------------------
echo - Content of the generated keystore for the $ALIAS alias
echo - ---------------------------------------------------------
keytool \
-list \
-alias $ALIAS \
-keystore $KEYSTORE_FILE \
-storetype $KEYSTORE_FILE_TYPE \
-storepass $KEYSTORE_PWD \
-v

echo "- ---------------------------------------------------------"
echo "- Generating tcmp https start script ."
echo "- ---------------------------------------------------------"
cat >$TCMP_HTTPS_SCRIPT<<EOF
#!/bin/bash

APP_HOME=./app
RUNTIME_HOME=./runtime

export PATH=\$RUNTIME_HOME/bin:\$PATH
#  -------------------------------------
#  -- Talend Cloud Migration Platform --
#  -------------------------------------
HOST=`hostname`
HTTPS_PORT=$SSL_SERVER_PORT
WEBAPP_URL=https://\$HOST:\$HTTPS_PORT/tcmp

echo
echo  You are about to start the Talend Cloud Migration Platform.
echo
echo  The application can be accessed at the url: \$WEBAPP_URL
echo
echo   !!IMPORTANT!!: TCMP requires Java 17 or higher.
echo
echo   Validate from the output below that you have a valid version.
echo
java -version
echo
echo   IMPORTANT:
echo   As TCMP is configured to use a self-signed certificate, the browser will display
echo   the warning 'Your connection is not private'. You can acknowledge and proceed to the page.
echo
read -r -t 8 -p "Press any key to continue ..."
clear

tcmp=\$APP_HOME/tcmp-R2024-01.jar

echo Talend Cloud Migration Platform is starting. Please wait ...

java \\
 -jar \$tcmp \\
 --server.ssl.key-store=$KEYSTORE_FILE \\
 --server.ssl.key-store-password=$KEYSTORE_PWD \\
 --server.ssl.key-store-type=$KEYSTORE_FILE_TYPE \\
 --server.ssl.key-alias=$ALIAS \\
 --server.ssl.key-password=$KEY_PWD \\
 --server.port=\$HTTPS_PORT
EOF

chmod +x $TCMP_HTTPS_SCRIPT
echo Done!

echo You can now use the script $TCMP_HTTPS_SCRIPT to start TCMP configured with HTTPS.

echo -n "Press enter to continue."

read -r -n 1 -t 5 -p "Press enter to continue."